% Script for constant current charge
%
% It solves 12 equations for 12 variables:
% $S_8$, $S_4$, $S_2$, S, $S_p$, $i_H$, $i_L$, V, $\eta_H$, $\eta_L$,
% $ENH$, $ENL$
%
% The calculated values are stored as rows in the matrix 'w'
% for example, w(5,1000) is the value for the 5th variable, $S_p$, at the 
% 5000th time step 
%
% The script calls onto the following functions:
% make_params, make_ic_ch_12, solve_dae12bv, plot_data_1run
% The script is called by - nobody
%
% Example plot data script included at the end
% 
% Subject to Creative Commons Attribution 4.0 International Public License
% see license.txt
% (c) Monica Marinescu, 23 Sept 2015, monica.marinescu@imperial.ac.uk

close all; clear all
addpath('../lib/')

%% Initialise problem
% ppt and BV are boolean parameters: true for model including the
% precipitation and Butler Volmer, false for model without either of
% these

ppt = true;
BV = true;

% Load parameters - any parameter can be changed from default by including
% following sytnax to make_params: 'ks', 4e-4
params = make_params('ppt', ppt,'BV',BV);

% Constant current value (negative = charge) and system sulfur mass
% for these values and this model the current corresponds to
% 0.85 (0.25C), 1.7 (0.5C), 3.4 (1C), 6.8 (2C)
I = -3.4; % A 
ms = 2.7; % g S

% Time axis
% if time_end is longer than the time it takes to charge, then the
% solver gives a warning and terminates the program
time_end = 2500; %s
time_N = ceil(40000); % maximum number of steps
ts=linspace(0, time_end, time_N); % time axis

% current axis for constant current
I_vec = I;
% alternatively, I_vec can be a vector specifying the value of current at
% every point in ts

%% Construct initial conditions
% initial conditions to correspond to the type of model chosen
% with/without precipitation;  with/without Butler Volmer

switch ppt
   case true
      % charge with ppt
      Vin = 2.0967; 
      %V chosen same as without ppt for comparison;
      % alternatively choose Vin as per end of discharge with ppt
      Sin = 5.4767e-5*ms;
      Spin = 0.4973*ms;
   case false
      % charge without ppt
      Vin = 2.0967; %V
      Sin = 0.4973*ms;
      Spin = 1e-6*ms;
end

% calculate the initial conditions for all other variables
w0 = make_ic_ch_12(params,I_vec(1), Vin, Sin, Spin);

%% Solve problem
% using the mex code (default) is much faster

% w=solve_dae12bv(ts,w0,4,params,I_vec,'mex',false);
w=solve_dae12bv(ts,w0,10,params,I_vec);
%% Plot data - example

plot_data_1run;
