function [param] = make_params(varargin)
% MAKE_PARAMS asigns parameter values
% 
% The function calls onto - nobody
% The function is called by run12_BV_disch.m and run12_BV_ch.m
%
% Subject to Creative Commons Attribution 4.0 International Public License
% see license.txt
% (c) Monica Marinescu, 23 Sept 2015, monica.marinescu@imperial.ac.uk

%% Input parser
% assigns default values to parameters, while allowing these to be changed 
% when those parameters are specifically included in the function call

%   Parameters      Default         Units
%    temp            298             K
%    R_area          0.96            m^2
%    ppt             true            bool
%    BV              true            bool

p = inputParser;

errorStr_num = 'Value must be positive, scalar, and numeric.'; 
validationFcn_num = @(x) assert(isnumeric(x) && isscalar(x) && (x > 0),errorStr_num);

errorStr_bool = 'Value must be boolean and scalar';
validationFcn_bool = @(x) assert(islogical(x) && isscalar(x) ,errorStr_bool);

addParameter(p,'temp',298,validationFcn_num)
addParameter(p,'R_area',0.960,validationFcn_num)

addParameter(p,'ppt',true,validationFcn_bool)
addParameter(p,'BV',true,validationFcn_bool)

parse(p,varargin{:})

%% Physical constants

param.R = 8.314462175; % 	mol-1 universal gas constant
param.F = 9.64853399e4; % C mol-1 Faraday constant
param.NA = 6.0221412927e23; % mol-1 Avogadro's number
param.e = 1.60217656535e-19; % C electron charge

param.T = p.Results.temp; % K assumed temperature

%% Cell-specific parameters

param.mm = 32; %g/mole S grams per mole S
param.EL0 = 2.195; % V reference potential for low plateau reaction
param.EH0 = 2.35; % V reference potential for high plateau reaction


%% Parameters related to charge transfer reactions (BV)

param.ar = p.Results.R_area; % m^2 reaction area

% exchange current density
switch p.Results.BV
    case true
        param.iHr = 1*param.ar; %A/m2*m^2
        param.iLr = 0.5*param.ar; %A/m2*m^2
    case false % large values such that overpotentials are very small for 
        % fixed reaction current
        param.iHr = param.ar*10^6; %A/m2*m^2
        param.iLr = param.ar*10^6; %A/m2*m^2
    otherwise
        error('invalid BV switch argument')
end


%% Parameters related to precipitation

param.rhoS = 2e6; % g/m^3 density of precipitated sulfur
param.vol = 0.0114e-3; %m^3 cell volume
param.Ksp = 0.0001; %g saturation mass of sulfur in electrolyte

% precipitation/dissolution rate
switch p.Results.ppt
    case true
        param.kp = 100; % $s^{-1}$
    case false
        param.kp = 0;% $s^{-1}$; v slow
    otherwise
        error('invalid ppt switch argument');
end


%% Shuttle rate

param.ks = 0.0002; %$s^{-1}$
%param.ks = 1e-10; % no shuttle, as ks = 0 causes numerical problems

end